#
# spec file for package python-hammett
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-hammett
Version:        0.10.0
Release:        2.4
Summary:        Fast python test runner
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/boxed/hammett
Source0:        https://github.com/boxed/hammett/archive/refs/tags/%{version}.tar.gz#/hammett-%{version}-gh.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{python_version_nodots} < 313
Requires:       python-astunparse
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Hammett is a fast python test runner that aims to be compatible with the parts
of pytest most people use (unless that conflicts with the goal of being fast).

%prep
%autosetup -p1 -n hammett-%{version}
echo "# Empty module" >> hammett/mark.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/hammett
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# the rest doesn't work: https://github.com/boxed/hammett/issues/12
testfiles="tests/test_di.py tests/test_misc.py"
%pyunittest $testfiles -v

%post
%python_install_alternative hammett

%postun
%python_uninstall_alternative hammett

%files %{python_files}
%doc AUTHORS.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/hammett
%{python_sitelib}/hammett
%{python_sitelib}/hammett-%{version}.dist-info

%changelog
* Thu Nov 21 2024 Dirk Müller <dmueller@suse.com>
- drop optional astunparse dependency for python 3.13
* Wed Nov 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.10.0
  * New programmatic option for not insert cwd
    into sys.path when running
  * Test names have the same syntax as pytest
* Fri Feb 16 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.9.4
  * Python 3.11 compatibility
  * Hooks for using Hammett as an API (for mutmut3)
  * Explicit fixture names didn't work
  * Support skipif
  * warns() without arguments fixed
  * conftest.py handling massively improved
- Release 0.9.3
  * Some fixes for pytest compatibility
  * The bare minimum to work with pytest-snapshot (but not be able
    to collect snapshots)
  * Random fixes. Super basic support for pytest_sessionstart
  * Support for specifying config in setup.cfg file. This is useful
    for e.g django: config=nomigrations
  * Experimental multiprocessing tests
  * A little fix for not breaking when test plugins think we have
    xdist
  * Fixes for running in no-cache mode, and some improvements for
    making mutation testing faster down the line
- Release 0.9.2
  * Fixed some really bad bugs relating to fixtures
- Release 0.9.1
  * Fixed plugins dynamically adding implicit fixtures. This fixes
    pytest-django
  * Implemented support for pytest.warns/hammett.warns
  * Make cache default off, since it's still rather flaky
- Release 0.9.0
  * Added support for caplog
  * Don't try to collect hidden files
- Release 0.8.0
  * Added support for the capsys feature from pytest
  * Fixed verbose output
  * Improved test feedback
  * Support for class based tests (like unittest)
  * Also search for *_test.py, since it seems pytest tries these
  * Compatibility with a funny little pytest feature where you can
    pass a list and not a list of a list to parametrize if you have
    just one argument
  * Pixed python 3.6 support
  * Sort local variables in error output
- Release 0.7.1
  * Fixed pretty bad cache invalidation bug. You might need to
    delete your .hammett-db file.
  * Attempt to get windows support
- Release 0.7.0
  * Added hammett specific tests files system. This means if you
    have a file my_project/foo.py hammett will look for
    my_project/foo__tests.py and testt/foo__tests.py for tests
    specific for that module.
  * If you have module specific tests (see previous point), you can
    now run tests for a module with hammett my_project.foo
  * Implemented a results cache. This means that if you haven't
    changed your source or tests hammett knows not to rerun the
    tests. If you have module specific tests it will run only the
    relevant tests for that module when you change the module.
  * Added hammett command line. Beware of using this after doing
    setup.py develop as setuptools then adds a huge overhead.
  * Support python 3.6
  * Optimizations
- Release 0.6.0
  * Added --durations feature
  * Improvements to skipping tests
  * Run tests in lexiographic order
  * Better assertion analysis
  * You can now pass hammett a directory on the command line and
    it'll do the right thing
  * Support names parameter of mark.parametrize() being a
    list/tuple
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.5.0
  * Implemented support for filtering tests based on markers. Also
    supports the marker[argument] syntax that goes beyond what pytest
    can do
  * Nicer output on failed tests
* Mon Mar 30 2020 pgajdos@suse.com
- initial vrsion 0.4.0, required by python-mutmut
